function res = isBounded(hs)
% isBounded - determines if a halfspace is bounded
%
% Syntax:
%    res = isBounded(hs)
%
% Inputs:
%    hs - halfspace object
%
% Outputs:
%    res - true/false
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Authors:       Mark Wetzlinger
% Written:       24-July-2023
% Last update:   ---
% Last revision: ---

% ------------------------------ BEGIN CODE -------------------------------

% always unbounded
res = false;

% ------------------------------ END OF CODE ------------------------------
